import React, { Fragment } from 'react'
import styled from 'styled-components'
import { compose, withHandlers, defaultProps, setDisplayName } from 'recompose'

import { Text, OpenModal, IconButton, marginHelper, withFetching } from './'

const PersonInvitation = ({
  id,
  withName,
  hasAnswer,
  isFetching,
  isLatestVersion,
  revokeInvitation,
  resendInvitation,
  person: { name, email },
  ...rest
}) => (
  <Root {...rest}>
    {withName && <Text>{name}</Text>}
    {!hasAnswer &&
      name !== 'Unassigned' && (
        <Fragment>
          <OpenModal
            confirmText="Resend"
            isFetching={isFetching}
            modalKey={`resend-${id}`}
            onConfirm={resendInvitation}
            subtitle={email}
            title="Resend the invitation?"
          >
            {showModal => (
              <IconButton
                fontIcon="resendIcon"
                mb={1}
                ml={2}
                onClick={showModal}
                secondary
              />
            )}
          </OpenModal>
          <OpenModal
            confirmText="Revoke"
            isFetching={isFetching}
            modalKey={`revoke-${id}`}
            onConfirm={revokeInvitation}
            subtitle={email}
            title="Revoke invitation?"
          >
            {showModal => (
              <IconButton
                fontIcon="removeIcon"
                mb={1}
                ml={2}
                onClick={showModal}
                secondary
              />
            )}
          </OpenModal>
        </Fragment>
      )}
    {hasAnswer &&
      isLatestVersion && (
        <Fragment>
          <OpenModal
            confirmText="Revoke"
            isFetching={isFetching}
            modalKey={`remove-${id}`}
            onConfirm={revokeInvitation}
            subtitle="Deleting the handling editor at this moment will also remove all his work."
            title="Revoke invitation?"
          >
            {showModal => (
              <IconButton
                fontIcon="removeIcon"
                mb={1}
                ml={2}
                onClick={showModal}
                secondary
              />
            )}
          </OpenModal>
        </Fragment>
      )}
  </Root>
)

export default compose(
  defaultProps({
    person: {
      name: 'Unassigned',
    },
    onRevoke: id => {},
    onResend: id => {},
  }),
  withFetching,
  withHandlers({
    revokeInvitation: ({ id, onRevoke, setFetching }) => props => {
      typeof onRevoke === 'function' && onRevoke(id, { ...props, setFetching })
    },
    resendInvitation: ({
      id,
      onResend,
      setFetching,
      person: { email },
    }) => props => {
      typeof onResend === 'function' &&
        onResend(email, { ...props, setFetching })
    },
  }),
  setDisplayName('PersonInvitation'),
)(PersonInvitation)

// #region styles
const Root = styled.div`
  align-items: center;
  display: flex;

  ${marginHelper};
`
// #endregion
