import React, { Fragment } from 'react'
import { get } from 'lodash'
import { withProps, compose } from 'recompose'
import styled from 'styled-components'
import { th } from '@pubsweet/ui-toolkit'
import { DateParser } from '@pubsweet/ui'

import {
  Label,
  Item,
  FileItem,
  Row,
  Text,
  withFilePreview,
  withFileDownload,
} from './'

const ReviewerReportAuthor = ({
  reviewFile,
  previewFile,
  downloadFile,
  publicReport,
  reviewerName,
  reviewerNumber,
  recommendation,
  showOwner = false,
  report: { submittedOn },
}) => (
  <Root>
    <Row justify="space-between" mb={2}>
      <Item justify="flex-end">
        {publicReport && (
          <Row mb={1}>
            <Item vertical>
              <Label mb={1 / 2}>Report</Label>
              <Text whiteSpace="pre-wrap">{publicReport}</Text>
            </Item>
          </Row>
        )}
        <Text customId ml={1} mr={1} whiteSpace="nowrap">
          {`Reviewer ${reviewerNumber}`}
        </Text>
        <DateParser timestamp={submittedOn}>
          {date => <Text>{date}</Text>}
        </DateParser>
      </Item>
    </Row>

    {reviewFile && (
      <Fragment>
        <Label mb={1 / 2}>Files</Label>
        <Row justify="flex-start" mb={1 / 2}>
          <Item flex={0} mr={1}>
            <FileItem
              item={reviewFile}
              onDownload={downloadFile}
              onPreview={previewFile}
            />
          </Item>
        </Row>
      </Fragment>
    )}
  </Root>
)

export default compose(
  withFilePreview,
  withFileDownload,
  withProps(({ report, journal: { recommendations = [] } }) => ({
    recommendation: get(
      recommendations.find(r => r.value === report.recommendation),
      'label',
    ),
    reviewFile: get(report, 'comments.0.files.0'),
    publicReport: get(report, 'comments.0.content'),
    reviewerName: `${get(report, 'reviewer.firstName', '')} ${get(
      report,
      'reviewer.lastName',
      '',
    )}`,
    reviewerNumber: get(report, 'reviewerNumber', ''),
  })),
)(ReviewerReportAuthor)

// #region styles
const Root = styled.div`
  background-color: ${th('colorBackgroundHue')};
  border: ${th('borderWidth')} ${th('borderStyle')} ${th('colorBackgroundHue3')};
  border-radius: ${th('borderRadius')};
  padding: calc(${th('gridUnit')} * 2);
  margin: ${th('gridUnit')};
`
// #endregion
