import React, { Fragment } from 'react'
import { isEmpty, get } from 'lodash'
import { withProps } from 'recompose'

import {
  Text,
  Item,
  Row,
  ContextualBox,
  ManuscriptFileList,
} from 'pubsweet-component-faraday-ui'

const ManuscriptMetadata = ({
  filesLabel,
  getSignedUrl,
  currentUser: { token },
  fragment: { files = {}, conflicts = {}, metadata: { abstract = '' } },
}) => (
  <Fragment>
    {!!abstract && (
      <Item mb={1}>
        <ContextualBox
          data-test-id="abstract-tab"
          label="Abstract"
          startExpanded
          transparent
        >
          <Text mb={1} mt={1}>
            {abstract}
          </Text>
        </ContextualBox>
      </Item>
    )}
    {conflicts.hasConflicts === 'yes' && (
      <Item mb={1}>
        <ContextualBox
          data-test-id="conflict-of-interest-tab"
          label="Conflict of Interest"
          transparent
        >
          <Row alignItems="center" justify="flex-start">
            <Text mb={1} mt={1}>
              Conflicts of interest:
            </Text>
            <Text ml={1 / 2}>{get(conflicts, 'message', '')}</Text>
          </Row>
          {get(conflicts, 'dataAvailabilityMessage', '') && (
            <Row alignItems="center" justify="flex-start">
              <Text mb={1} mt={1}>
                Data availability statment:
              </Text>
              <Text ml={1 / 2}>
                {get(conflicts, 'dataAvailabilityMessage', '')}
              </Text>
            </Row>
          )}
          {get(conflicts, 'fundingMessage', '') && (
            <Row alignItems="center" justify="flex-start">
              <Text mb={1} mt={1}>
                Funding statment:
              </Text>
              <Text ml={1 / 2}>{get(conflicts, 'fundingMessage', '')}</Text>
            </Row>
          )}
        </ContextualBox>
      </Item>
    )}
    {!isEmpty(files) && (
      <Item mb={1}>
        <ContextualBox data-test-id="files-tab" label={filesLabel} transparent>
          <ManuscriptFileList
            files={files}
            getSignedUrl={getSignedUrl}
            token={token}
          />
        </ContextualBox>
      </Item>
    )}
  </Fragment>
)

export default withProps(({ fragment: { files } }) => ({
  filesLabel: `Files (${get(files, 'manuscripts', []).length +
    get(files, 'coverLetter', []).length +
    get(files, 'supplementary', []).length})`,
}))(ManuscriptMetadata)
