const { has, get } = require('lodash')
const {
  services,
  authsome: authsomeHelper,
} = require('pubsweet-component-helper-service')

module.exports = models => async (req, res) => {
  const { collectionId } = req.params

  try {
    const collection = await models.Collection.find(collectionId)
    const authsome = authsomeHelper.getAuthsome(models)
    const target = {
      path: req.route.path,
    }
    const canArchive = await authsome.can(req.user, 'PATCH', target)

    if (!collection)
      return res.status(404).json({
        error: `Collection not found`,
      })

    if (!canArchive)
      return res.status(403).json({
        error: 'Unauthorized',
      })

    if (!has(collection, 'status')) {
      return res.status(400).json({
        error: 'You cannot delete manuscripts while in draft.',
      })
    }

    if (get(collection, 'status') === 'deleted') {
      return res.status(400).json({
        error: 'Manuscript already deleted',
      })
    }

    if (has(collection, 'status')) {
      collection.status = 'deleted'
      await collection.save()
    }
    return res.status(200).json(collection)
  } catch (e) {
    const notFoundError = await services.handleNotFoundError(e, 'Collection')
    return res.status(notFoundError.status).json({
      error: notFoundError.message,
    })
  }
}
